summaryrefslogtreecommitdiffstats
path: root/styles/phase
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-09-29 01:21:58 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-09-29 01:21:58 -0500
commit54e824664fbb115686c390082459c1b66d606905 (patch)
treefd18434509f44a55444778469da62acc761f9514 /styles/phase
parent623deae25963f155f0c10011e59b10e857c0db18 (diff)
downloadtdeartwork-54e824664fbb115686c390082459c1b66d606905.tar.gz
tdeartwork-54e824664fbb115686c390082459c1b66d606905.zip
Rename remaining KDE strings to TDE, with the exception of a couple of build variables
Diffstat (limited to 'styles/phase')
-rw-r--r--styles/phase/phasestyle.cpp10
-rw-r--r--styles/phase/phasestyle.h2
2 files changed, 6 insertions, 6 deletions
diff --git a/styles/phase/phasestyle.h b/styles/phase/phasestyle.h
index 8922960b..2d2273cc 100644
--- a/styles/phase/phasestyle.h
+++ b/styles/phase/phasestyle.h
@@ -1,7 +1,7 @@
//////////////////////////////////////////////////////////////////////////////
// phasestyle.h
// -------------------
-// TQt/KDE widget style
+// TQt/TDE widget style
// -------------------
// Copyright (c) 2004 David Johnson <david@usermode.org>
//
diff --git a/styles/phase/phasestyle.cpp b/styles/phase/phasestyle.cpp
index 008e1b15..952ade00 100644
--- a/styles/phase/phasestyle.cpp
+++ b/styles/phase/phasestyle.cpp
@@ -1,7 +1,7 @@
//////////////////////////////////////////////////////////////////////////////
// phasestyle.cpp
// -------------------
-// TQt/KDE widget style
+// TQt/TDE widget style
// -------------------
// Copyright (c) 2004 David Johnson
// Please see the header file for copyright and license information.
@@ -17,7 +17,7 @@
// differs from the TQt default of giving them PaletteButton backgrounds.
// Menubars have normal gradients, toolbars have reverse.
//
// Some toolbars are not part of a TQMainWindows, such as in a KDE file dialog.
// In these cases we treat the toolbar as "floating" and paint it flat.
//
//////////////////////////////////////////////////////////////////////////////
@@ -89,7 +89,7 @@ PhaseStyle::PhaseStyle()
if (gradients_) { // don't bother setting if already false
gradients_ =
settings.readBoolEntry("/phasestyle/Settings/gradients", true);
- contrast = 100 + settings.readNumEntry("/TQt/KDE/contrast", 5);
+ contrast = 100 + settings.readNumEntry("/TQt/TDE/contrast", 5);
}
highlights_ =
settings.readBoolEntry("/phasestyle/Settings/highlights", true);
@@ -2277,7 +2277,7 @@ bool PhaseStyle::objectEventHandler( const TQStyleControlElementData &ceData, Co
if (event->type() == TQEvent::Paint) {
// make sure we do the most specific stuff first
// KDE Toolbar Widget
// patch by Daniel Brownlees <dbrownlees@paradise.net.nz>
if (object->parent() && !qstrcmp(object->name(), KTOOLBARWIDGET)) {
if (0 == (widget = ::tqqt_cast<TQWidget*>(object))) return false;
@@ -2485,6 +2485,6 @@ TQStyle* PhaseStylePlugin::create(const TQString& key)
return 0;
}
-KDE_Q_EXPORT_PLUGIN(PhaseStylePlugin)
+TDE_Q_EXPORT_PLUGIN(PhaseStylePlugin)
#include "phasestyle.moc"
@@ -17,7 +17,7 @@
// Menubars have normal gradients, toolbars have reverse.
//
-// Some toolbars are not part of a TQMainWindows, such as in a KDE file dialog.
+// Some toolbars are not part of a TQMainWindows, such as in a TDE file dialog.
// In these cases we treat the toolbar as "floating" and paint it flat.
//
@@ -2277,7 +2277,7 @@ bool PhaseStyle::objectEventHandler( const TQStyleControlElementData &ceData, Co
if (event->type() == TQEvent::Paint) {
// make sure we do the most specific stuff first
- // KDE Toolbar Widget
+ // TDE Toolbar Widget
// patch by Daniel Brownlees <dbrownlees@paradise.net.nz>
if (object->parent() && !qstrcmp(object->name(), KTOOLBARWIDGET)) {